@@ -1,5 +1,8 @@
 // Use LANG environment variable to choose locale
-pref("intl.locale.matchOS", true);
+pref("intl.locale.requested", "");
+
+// Use system-provided dictionaries
+pref("spellchecker.dictionary_path", "/usr/share/hunspell");
 
 // Disable default mailer checking.
 pref("mail.shell.checkDefaultMail", false);
